@@ -67,6 +67,7 @@ class BadLiftValu(SynErr): pass
 class BadPropDef(SynErr): pass
 class BadTypeDef(SynErr): pass
 class BadTypeValu(SynErr): pass
+class BadJsonText(SynErr): pass
 
 class BadArg(SynErr):
     ''' Improper function arguments '''
@@ -95,7 +96,9 @@ class BadUrl(SynErr): pass
 
 class CantDelCmd(SynErr): pass
 class CantDelNode(SynErr): pass
+class CantDelForm(SynErr): pass
 class CantDelProp(SynErr): pass
+class CantDelType(SynErr): pass
 class CantDelUniv(SynErr): pass
 class CantMergeView(SynErr): pass
 class CantRevLayer(SynErr): pass
@@ -125,6 +128,7 @@ class DbOutOfSpace(SynErr): pass
 class DupName(SynErr): pass
 class DupIden(SynErr): pass
 class DupFileName(SynErr): pass
+class DupFormName(SynErr): pass
 class DupPropName(SynErr): pass
 class DupRoleName(SynErr): pass
 class DupTagPropName(SynErr): pass
@@ -141,6 +145,7 @@ class InconsistentStorage(SynErr):
 
 class IsFini(SynErr): pass
 class IsReadOnly(SynErr): pass
+class IsDeprLocked(SynErr): pass
 class IsRuntForm(SynErr): pass
 
 class LayerInUse(SynErr): pass
@@ -217,6 +222,7 @@ class SlabAlreadyOpen(SynErr): pass
 class SpawnExit(SynErr): pass
 class FeatureNotSupported(SynErr): pass
 
+class HitLimit(SynErr): pass
 class ReadOnlyLayer(SynErr): pass
 class ReadOnlyProp(SynErr): pass
 class RecursionLimitHit(SynErr): pass
@@ -236,16 +242,3 @@ class StormRuntimeError(SynErr): pass
 class StormVarListError(StormRuntimeError): pass
 
 class TeleRedir(SynErr): pass
-
-class StormCtrlFlow(Exception):
-    def __init__(self, item=None):
-        self.item = item
-
-class StormBreak(StormCtrlFlow):
-    pass
-
-class StormContinue(StormCtrlFlow):
-    pass
-
-class StormReturn(StormCtrlFlow):
-    pass
