@@ -82,6 +82,10 @@ class CellApi(s_base.Base):
         self.user = user
         sess = self.link.get('sess')  # type: s_daemon.Sess
         sess.user = user
+        await self.initCellApi()
+
+    async def initCellApi(self):
+        pass
 
     async def allowed(self, perm, default=None):
         '''
@@ -515,12 +519,16 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         },
         'auth:passwd': {
             'description': 'Set to <passwd> (local only) to bootstrap the root user password.',
-            'type': 'string'
+            'type': 'string',
+        },
+        'auth:anon': {
+            'description': 'Allow anonymous telepath access by mapping to the given user name.',
+            'type': 'string',
         },
         'nexslog:en': {
             'default': False,
             'description': 'Record all changes to the cell.  Required for mirroring (on both sides).',
-            'type': 'boolean'
+            'type': 'boolean',
         },
         'nexslog:async': {
             'default': False,
@@ -709,6 +717,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
     async def getNexsIndx(self):
         return await self.nexsroot.index()
 
+    @s_nexus.Pusher.onPushAuto('nexslog:setindex')
+    async def setNexsIndx(self, indx):
+        return await self.nexsroot.setindex(indx)
+
     async def promote(self):
         '''
         Transform this cell from a passive follower to
@@ -1307,7 +1319,8 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         Notes:
             Boot time configuration data is placed in the argument group called ``config``.
             This adds default ``dirn``, ``--telepath``, ``--https`` and ``--name`` arguements to the argparser instance.
-            Configuration values which have the ``hideconf`` value set to True are not added to the argparser instance.
+            Configuration values which have the ``hideconf`` or ``hidecmdl`` value set to True are not added to the
+            argparser instance.
 
         Returns:
             argparse.ArgumentParser: A ArgumentParser for the Cell.
@@ -1452,8 +1465,21 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
     async def _getCellUser(self, mesg):
 
         auth = mesg[1].get('auth')
+
         if auth is None:
-            raise s_exc.AuthDeny(mesg='Unable to find cell user')
+
+            anonuser = self.conf.get('auth:anon')
+            if anonuser is None:
+                raise s_exc.AuthDeny(mesg='Unable to find cell user')
+
+            user = await self.auth.getUserByName(anonuser)
+            if user is None:
+                raise s_exc.AuthDeny(mesg=f'Anon user ({anonuser}) is not found.')
+
+            if user.isLocked():
+                raise s_exc.AuthDeny(mesg=f'Anon user ({anonuser}) is locked.')
+
+            return user
 
         name, info = auth
 
