@@ -94,7 +94,7 @@ reqValidLdef = s_config.getJsValidator({
         'iden': {'type': 'string', 'pattern': s_config.re_iden},
         'creator': {'type': 'string', 'pattern': s_config.re_iden},
         'lockmemory': {'type': 'boolean'},
-        'logedits': {'type': 'boolean'}, 'default': True,
+        'logedits': {'type': 'boolean', 'default': True},
         'name': {'type': 'string'},
     },
     'additionalProperties': True,
@@ -1003,6 +1003,10 @@ class Layer(s_nexus.Pusher):
         self.growsize = self.layrinfo.get('growsize')
         self.logedits = self.layrinfo.get('logedits')
 
+        # slim hooks to avoid async/fire
+        self.nodeAddHook = None
+        self.nodeDelHook = None
+
         path = s_common.genpath(self.dirn, 'layer_v2.lmdb')
 
         self.fresh = not os.path.exists(path)
@@ -1422,7 +1426,7 @@ class Layer(s_nexus.Pusher):
 
         return await self.layrslab.countByPref(abrv, db=self.bytag)
 
-    async def getPropCount(self, formname, propname=None):
+    async def getPropCount(self, formname, propname=None, maxsize=None):
         '''
         Return the number of property rows in the layer for the given form/prop.
         '''
@@ -1431,7 +1435,7 @@ class Layer(s_nexus.Pusher):
         except s_exc.NoSuchAbrv:
             return 0
 
-        return await self.layrslab.countByPref(abrv, db=self.byprop)
+        return await self.layrslab.countByPref(abrv, db=self.byprop, maxsize=maxsize)
 
     async def liftByTag(self, tag, form=None):
 
@@ -1668,6 +1672,7 @@ class Layer(s_nexus.Pusher):
                 self.layrslab.put(abrv + indx, buid, db=self.byprop)
 
         self.formcounts.inc(form)
+        if self.nodeAddHook is not None: self.nodeAddHook()
 
         retn = [
             (EDIT_NODE_ADD, (valu, stortype), ())
@@ -1709,6 +1714,7 @@ class Layer(s_nexus.Pusher):
                 self.layrslab.delete(abrv + indx, buid, db=self.byprop)
 
         self.formcounts.inc(form, valu=-1)
+        if self.nodeDelHook is not None: self.nodeDelHook()
 
         self._wipeNodeData(buid)
         # TODO edits to become async so we can sleep(0) on large deletes?
@@ -1963,6 +1969,9 @@ class Layer(s_nexus.Pusher):
         if sode.get('form') is None:
             self.setSodeDirty(buid, sode, form)
 
+        if oldb is not None:
+            oldv = s_msgpack.un(oldb)
+
         self.dataslab.put(abrv, buid, db=self.dataname)
 
         return (
