@@ -12,6 +12,7 @@ import synapse.lib.nexus as s_nexus
 import synapse.lib.config as s_config
 import synapse.lib.spooled as s_spooled
 import synapse.lib.trigger as s_trigger
+import synapse.lib.stormctrl as s_stormctrl
 import synapse.lib.stormtypes as s_stormtypes
 
 logger = logging.getLogger(__name__)
@@ -181,10 +182,14 @@ class View(s_nexus.Pusher):  # type: ignore
             async for item in self.eval(text, opts=opts):
                 await asyncio.sleep(0)  # pragma: no cover
 
-        except s_exc.StormReturn as e:
-
+        except s_stormctrl.StormReturn as e:
+            # Catch return( ... ) values and return the
+            # primitive version of that item.
             return await s_stormtypes.toprim(e.item)
 
+        # Any other exceptions will be raised to
+        # callers as expected.
+
     async def nodes(self, text, opts=None):
         '''
         A simple non-streaming way to return a list of nodes.
@@ -245,6 +250,9 @@ class View(s_nexus.Pusher):  # type: ignore
                         async for item in snap.storm(text, opts=opts, user=user):
                             count += 1
 
+            except s_stormctrl.StormExit:
+                pass
+
             except asyncio.CancelledError:
                 logger.warning('Storm runtime cancelled.')
                 cancelled = True
@@ -685,3 +693,14 @@ class View(s_nexus.Pusher):  # type: ignore
         return {
             'iden': self.iden,
         }
+
+    async def addNodeEdits(self, edits, meta):
+        '''
+        A telepath compatible way to apply node edits to a view.
+
+        NOTE: This does cause trigger execution.
+        '''
+        user = await self.core.auth.reqUser(meta.get('user'))
+        async with await self.snap(user=user) as snap:
+            # go with the anti-pattern for now...
+            await snap.applyNodeEdits(edits)
