@@ -488,6 +488,16 @@ class LayerTest(s_t_utils.SynTest):
             splices = await alist(layr.splices(spliceoffs, 10))
             self.len(0, splices)
 
+            # Make sure nodedata edits have oldv set
+            nedit = await layr.iterNodeEditLog(spliceoffs[0]).__anext__()
+            self.eq(nedit[1][0][2][0][1], ('baz', 'nodedataiscool', None))
+
+            spliceoffs = (spliceoffs[0] + 1, 0, 0)
+
+            await nodes[0].setData('baz', 'stillcool')
+            nedit = await layr.iterNodeEditLog(spliceoffs[0]).__anext__()
+            self.eq(nedit[1][0][2][0][1], ('baz', 'stillcool', 'nodedataiscool'))
+
             # Convert a node:del splice
             await core.nodes('test:str=foo | delnode')
 
@@ -1007,3 +1017,16 @@ class LayerTest(s_t_utils.SynTest):
 
             for layr in core.layers.values():
                 self.eq(layr.layrvers, 3)
+
+    async def test_layer_logedits_default(self):
+
+        with self.getTestDir() as dirn:
+
+            layrinfo = {
+                'iden': s_common.guid(),
+                'creator': s_common.guid(),
+                'lockmemory': False,
+            }
+            s_layer.reqValidLdef(layrinfo)
+            layr = await s_layer.Layer.anit(layrinfo, dirn)
+            self.true(layr.logedits)
