@@ -154,3 +154,56 @@ class StormlibModelTest(s_test.SynTest):
                 elist = await core.callStorm('return($lib.model.edge.list())')
                 self.sorteq([('cat', 'ran up a tree'), ('dog', ''), ('refs', '')],
                             [(e[0], e[1].get('doc', '')) for e in elist])
+
+    async def test_stormlib_model_depr(self):
+
+        with self.getTestDir() as dirn:
+
+            async with self.getTestCore(dirn=dirn) as core:
+
+                # create both a deprecated form and a node with a deprecated prop
+                await core.nodes('[ ou:org=* :sic=1234 ou:hasalias=($node.repr(), foobar) ]')
+
+                with self.raises(s_exc.NoSuchProp):
+                    await core.nodes('model.deprecated.lock newp:newp')
+
+                # lock a prop and a form/type
+                await core.nodes('model.deprecated.lock ou:org:sic')
+                await core.nodes('model.deprecated.lock ou:hasalias')
+
+                with self.raises(s_exc.IsDeprLocked):
+                    await core.nodes('ou:org [ :sic=5678 ]')
+
+                with self.raises(s_exc.IsDeprLocked):
+                    await core.nodes('[ou:hasalias=(*, hehe)]')
+
+                mesgs = await core.stormlist('model.deprecated.locks')
+                self.stormIsInPrint('ou:org:sic: True', mesgs)
+                self.stormIsInPrint('ou:hasalias: True', mesgs)
+                self.stormIsInPrint('it:reveng:funcstr: False', mesgs)
+
+                await core.nodes('model.deprecated.lock --unlock ou:org:sic')
+                await core.nodes('ou:org [ :sic=5678 ]')
+                await core.nodes('model.deprecated.lock ou:org:sic')
+
+            # ensure that the locks persisted and got loaded correctly
+            async with self.getTestCore(dirn=dirn) as core:
+
+                mesgs = await core.stormlist('model.deprecated.check')
+                # warn due to unlocked
+                self.stormIsInWarn('it:reveng:funcstr', mesgs)
+                # warn due to existing
+                self.stormIsInWarn('ou:org:sic', mesgs)
+                self.stormIsInWarn('ou:hasalias', mesgs)
+                self.stormIsInPrint('Your cortex contains deprecated model elements', mesgs)
+
+                await core.nodes('model.deprecated.lock *')
+
+                mesgs = await core.stormlist('model.deprecated.locks')
+                self.stormIsInPrint('it:reveng:funcstr: True', mesgs)
+
+                await core.nodes('ou:org [ -:sic ]')
+                await core.nodes('ou:hasalias | delnode')
+
+                mesgs = await core.stormlist('model.deprecated.check')
+                self.stormIsInPrint('Congrats!', mesgs)
