@@ -10,6 +10,14 @@ logger = logging.getLogger(__name__)
 
 class InetModelTest(s_t_utils.SynTest):
 
+    async def test_model_inet_basics(self):
+        async with self.getTestCore() as core:
+            self.len(1, await core.nodes('[ inet:web:hashtag="#hehe" ]'))
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[ inet:web:hashtag="foo" ]')
+            with self.raises(s_exc.BadTypeValu):
+                await core.nodes('[ inet:web:hashtag="#foo bar" ]')
+
     async def test_ipv4_lift_range(self):
 
         async with self.getTestCore() as core:
@@ -700,6 +708,27 @@ class InetModelTest(s_t_utils.SynTest):
                 node = await snap.addNode(formname, valu_str, props=input_props)
                 self.checkNode(node, (expected_ndef, expected_props))
 
+            # > / < lifts and filters
+            self.len(4, await core.nodes('[inet:ipv4=0 inet:ipv4=1 inet:ipv4=2 inet:ipv4=3]'))
+            # Lifts
+            with self.raises(OverflowError):
+                await core.nodes('inet:ipv4<0')
+            self.len(1, await core.nodes('inet:ipv4<=0'))
+            self.len(1, await core.nodes('inet:ipv4<1'))
+            self.len(3, await core.nodes('inet:ipv4<=2'))
+            self.len(2, await core.nodes('inet:ipv4>2'))
+            self.len(3, await core.nodes('inet:ipv4>=2'))
+            self.len(0, await core.nodes('inet:ipv4>=255.0.0.1'))
+            # This value wraps around and lifts starting from zero.
+            self.len(5, await core.nodes('inet:ipv4>=$foo', {'vars': {'foo': 0xFFFFFFFF + 1}}))
+            # Filters
+            self.len(0, await core.nodes('.created +inet:ipv4<0'))
+            self.len(1, await core.nodes('.created +inet:ipv4<1'))
+            self.len(3, await core.nodes('.created +inet:ipv4<=2'))
+            self.len(2, await core.nodes('.created +inet:ipv4>2'))
+            self.len(3, await core.nodes('.created +inet:ipv4>=2'))
+            self.len(0, await core.nodes('.created +inet:ipv4>=255.0.0.1'))
+
     async def test_ipv6(self):
         formname = 'inet:ipv6'
         async with self.getTestCore() as core:
@@ -1269,7 +1298,7 @@ class InetModelTest(s_t_utils.SynTest):
             # Type Tests
             t = core.model.type(formname)
 
-            self.raises(s_exc.BadTypeValu, t.norm, 'vertex.link/person1')
+            self.raises(s_exc.BadTypeValu, t.norm, 'vertex.link,person1')
             enorm = ('vertex.link', 'person1')
             edata = {'subs': {'user': 'person1',
                               'site': 'vertex.link',
@@ -1285,10 +1314,12 @@ class InetModelTest(s_t_utils.SynTest):
                 'avatar': 'sha256:' + 64 * 'a',
                 'dob': -64836547200000,
                 'email': 'brutus@vertex.link',
+                'linked:accts': (('twitter.com', 'brutus'), ('linkedin.com', 'brutester'), ('linkedin.com', 'brutester')),
                 'latlong': '0,0',
                 'place': place,
                 'loc': 'sol',
                 'name': 'ካሳር',
+                'aliases': ('foo', 'bar', 'bar'),
                 'name:en': 'brutus',
                 'occupation': 'jurist',
                 'passwd': 'hunter2',
@@ -1300,6 +1331,7 @@ class InetModelTest(s_t_utils.SynTest):
                 'tagline': 'Taglines are not tags',
                 'url': 'https://blogs.vertex.link/',
                 'webpage': 'https://blogs.vertex.link/brutus',
+                'recovery:email': 'recovery@vertex.link',
             }
 
             expected_ndef = (formname, ('blogs.vertex.link', 'brutus'))
@@ -1308,11 +1340,14 @@ class InetModelTest(s_t_utils.SynTest):
                 'site': valu[0].lower(),
                 'user': valu[1].lower(),
                 'latlong': (0.0, 0.0),
+                'aliases': ('bar', 'foo'),
+                'linked:accts': (('linkedin.com', 'brutester'), ('twitter.com', 'brutus')),
                 'place': place,
                 'phone': '5555555555',
                 'realname': 'брут',
                 'signup:client': 'tcp://0.0.0.4',
                 'signup:client:ipv4': 4,
+                'recovery:email': 'recovery@vertex.link',
             })
 
             async with await core.snap() as snap:
@@ -1320,6 +1355,8 @@ class InetModelTest(s_t_utils.SynTest):
                 self.eq(node.ndef, expected_ndef)
                 self.checkNode(node, (expected_ndef, expected_props))
 
+            self.len(2, await core.nodes('inet:web:acct=(blogs.vertex.link, brutus) :linked:accts -> inet:web:acct'))
+
     async def test_web_action(self):
         formname = 'inet:web:action'
         valu = 32 * 'a'
@@ -1413,6 +1450,7 @@ class InetModelTest(s_t_utils.SynTest):
         place = s_common.guid()
         input_props = {
             'name': 'The coolest group',
+            'aliases': ('foo', 'bar', 'bar'),
             'name:en': 'The coolest group (in english)',
             'url': 'https://vertex.link/CoolGroup',
             'avatar': 64 * 'f',
@@ -1428,6 +1466,7 @@ class InetModelTest(s_t_utils.SynTest):
             'site': valu[0],
             'id': valu[1],
             'name': 'The coolest group',
+            'aliases': ('bar', 'foo'),
             'name:en': 'The coolest group (in english)',
             'url': 'https://vertex.link/CoolGroup',
             'avatar': 'sha256:' + 64 * 'f',
@@ -1527,6 +1566,7 @@ class InetModelTest(s_t_utils.SynTest):
     async def test_web_post(self):
         formname = 'inet:web:post'
         valu = 32 * 'a'
+        plac = s_common.guid()
         input_props = {
             'acct': ('vertex.link', 'vertexmc'),
             'text': 'my cooL POST',
@@ -1536,6 +1576,14 @@ class InetModelTest(s_t_utils.SynTest):
             'file': 64 * 'f',
             'replyto': 32 * 'b',
             'repost': 32 * 'c',
+
+            'hashtags': '#foo,#bar,#foo',
+            'mentions:users': 'vertex.link/visi,vertex.link/whippit',
+            'mentions:groups': 'vertex.link/ninjas',
+
+            'loc': 'ru',
+            'place': plac,
+            'latlong': (20, 30),
         }
         expected_props = {
             'acct': ('vertex.link', 'vertexmc'),
@@ -1549,6 +1597,14 @@ class InetModelTest(s_t_utils.SynTest):
             'file': 'sha256:' + 64 * 'f',
             'replyto': 32 * 'b',
             'repost': 32 * 'c',
+
+            'hashtags': ('#bar', '#foo'),
+            'mentions:users': (('vertex.link', 'visi'), ('vertex.link', 'whippit')),
+            'mentions:groups': (('vertex.link', 'ninjas'),),
+
+            'loc': 'ru',
+            'place': plac,
+            'latlong': (20, 30),
         }
 
         node2 = s_common.guid()
@@ -1566,6 +1622,7 @@ class InetModelTest(s_t_utils.SynTest):
 
                 node = await snap.addNode('inet:web:post', node2, props=inputs2)
                 self.checkNode(node, (('inet:web:post', node2), expected2))
+                self.len(2, await core.nodes('inet:web:post -> inet:web:hashtag'))
 
     async def test_whois_contact(self):
         formname = 'inet:whois:contact'
